@@ -84,23 +84,14 @@ class BaseDocumentCloudClient(object):
             # Pull the document_ids out of the params
             document_ids = params.get("document_ids")
             del params['document_ids']
-            params = urllib.urlencode(params, doseq=True)
+            params = urllib.urlencode(params)
             # These need to be specially formatted in the style documentcloud
             # expects arrays. The example they provide is:
             # ?document_ids[]=28-boumediene&document_ids[]=207-academy&document_ids[]=30-insider-trading
             params += "".join(['&document_ids[]=%s' % id for id in document_ids])
-        # More special case handler of key/value data tags, if they exist
-        elif params.get("data", None):
-            # Pull them out of the dict
-            data = params.get("data")
-            del params['data']
-            params = urllib.urlencode(params, doseq=True)
-            # Format them in the style documentcloud expects
-            # ?data['foo']=bar&data['tit']=tat
-            params += "".join(['&data[%s]=%s' % (key, value) for key, value in data.items()])
         else:
             # Otherwise, we can just use the vanilla urllib prep method
-            params = urllib.urlencode(params, doseq=True)
+            params = urllib.urlencode(params)
         # Make the request
         content = self._make_request(
             self.BASE_URI + method,
@@ -113,7 +104,7 @@ class BaseDocumentCloudClient(object):
         """
         # Encode params if they exist
         if params:
-            params = urllib.urlencode(params, doseq=True)
+            params = urllib.urlencode(params)
         content = self._make_request(
             self.BASE_URI + method,
             params,
@@ -200,8 +191,8 @@ class DocumentClient(BaseDocumentCloudClient):
     
     @credentials_required
     def upload(self, path, title=None, source=None, description=None,
-        related_article=None, published_url=None, access='private',
-        project=None, data=None, secure=False):
+        related_article=None, published_url=None,
+        access='private', project=None):
         """
         Upload a PDF or other image file to DocumentCloud.
         
@@ -227,18 +218,14 @@ class DocumentClient(BaseDocumentCloudClient):
         if published_url: params['published_url'] = published_url
         if access: params['access'] = access
         if project: params['project'] = project
-        if data:
-            for key, value in data.items():
-                params['data[%s]' % key] = value
-        if secure: params['secure'] = 'true'
         # Make the request
         response = self._make_request(self.BASE_URI + 'upload.json', params, MultipartPostHandler)
         return self.get(json.loads(response)['id'])
     
     @credentials_required
     def upload_directory(self, path, source=None, description=None,
-        related_article=None, published_url=None, access='private',
-        project=None, data=None, secure=False):
+        related_article=None, published_url=None,
+        access='private', project=None):
         """
         Uploads all the PDFs in the provided directory.
         
@@ -259,7 +246,7 @@ class DocumentClient(BaseDocumentCloudClient):
         for pdf_path in path_list:
             obj = self.upload(pdf_path, source=source, description=description,
                 related_article=related_article, published_url=published_url,
-                access=access, project=project, data=data, secure=secure)
+                access=access, project=project)
             obj_list.append(obj)
         # Pass back the list of documents
         return obj_list
@@ -364,7 +351,7 @@ class ProjectClient(BaseDocumentCloudClient):
             'title': title,
         }
         if description: params['description'] = description
-        params = urllib.urlencode(params, doseq=True)
+        params = urllib.urlencode(params)
         if document_ids:
             # These need to be specially formatted in the style documentcloud
             # expects arrays. The example they provide is:
@@ -480,7 +467,6 @@ class Document(BaseAPIObject):
             * related_article
             * access
             * published_url
-            * data key/value pairs
         
         Returns nothing.
         """
@@ -491,16 +477,9 @@ class Document(BaseAPIObject):
             related_article=self.resources.related_article,
             published_url=self.resources.published_url,
             access=self.access,
-            data=self.data,
         )
         self._connection.put('documents/%s.json' % self.id, params)
     
-    def save(self):
-        """
-        An alias to `'put` that post changes back to DocumentCloud
-        """
-        self.put()
-
     def delete(self):
         """
         Deletes this object from documentcloud.org.
@@ -535,26 +514,6 @@ class Document(BaseAPIObject):
             return obj.contributor_organization
     contributor_organization = property(get_contributor_organization)
     
-    def set_data(self, data):
-        """
-        Update the data attribute, making sure it's a dictionary.
-        """
-        if type(data) != type({}):
-            raise TypeError("This attribute must be a dictionary.")
-        self.__dict__[u'data'] = data
-    
-    def get_data(self):
-        """
-        Fetch the data field if it does not exist.
-        """
-        try:
-            return self.__dict__[u'data']
-        except KeyError:
-            obj = self._connection.documents.get(id=self.id)
-            self.__dict__[u'data'] = obj.data
-            return obj.data
-    data = property(get_data, set_data)
-    
     def get_annotations(self):
         """
         Fetch the annotations field if it does not exist.
@@ -909,12 +868,6 @@ class Project(BaseAPIObject):
         )
         self._connection.put('projects/%s.json' % self.id, params)
     
-    def save(self):
-        """
-        An alias to `'put` that post changes back to DocumentCloud
-        """
-        self.put()
-    
     def delete(self):
         """
         Deletes this object from documentcloud.org.
